===============================
imeji
===============================

.. image:: https://travis-ci.org/imeji-community/pyimeji.png?branch=master
        :target: https://travis-ci.org/imeji-community/pyimeji

.. image:: https://readthedocs.org/projects/pyimeji/badge/?version=latest
        :target: https://readthedocs.org/projects/pyimeji/?badge=latest
        :alt: Documentation Status

A python wrapper for the `imeji <http://imeji.org>`_ API

Features
--------

- create and retrieve collections and items.
- delete items.
- retrieve profiles.

Requirements
------------

- Python >= 2.7 or >= 3.4

License
-------

Apache 2.0
